<?php
/**
 * Plugin Name:           GamiPress - Thrive Quiz Builder integration
 * Plugin URI:            https://wordpress.org/plugins/gamipress-thrive-quiz-builder-integration/
 * Description:           Connect GamiPress with Thrive Quiz Builder.
 * Version:               1.0.1
 * Author:                GamiPress
 * Author URI:            https://gamipress.com/
 * Text Domain:           gamipress-thrive-quiz-builder-integration
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.2
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               GamiPress\Thrive_Quiz_Builder
 * @author                GamiPress
 * @copyright             Copyright (c) GamiPress
 */

final class GamiPress_Thrive_Quiz_Builder {

    /**
     * @var         GamiPress_Thrive_Quiz_Builder $instance The one true GamiPress_Thrive_Quiz_Builder
     * @since       1.0.1
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.1
     * @return      GamiPress_Thrive_Quiz_Builder self::$instance The one true GamiPress_Thrive_Quiz_Builder
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new GamiPress_Thrive_Quiz_Builder();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.1
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'GAMIPRESS_THRIVE_QUIZ_BUILDER_VER', '1.0.1' );

        // Plugin path
        define( 'GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'GAMIPRESS_THRIVE_QUIZ_BUILDER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.1
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/admin.php';
            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/functions.php';
            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/listeners.php';
            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/requirements.php';
            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/rules-engine.php';
            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/scripts.php';
            require_once GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . 'includes/triggers.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.1
     * @return      void
     */
    private function hooks() {
        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.1
     */
    public function admin_notices() {
        ?>
        <div id="message" class="notice notice-error is-dismissible gamipress-integration-deprecated">
            <p><?php print( __( 'GamiPress - Thrive Quiz Builder integration is not required anymore since now all integrations are included in GamiPress core.', 'gamipress-gamipress-thrive-quiz-builder-integration' ) ); ?></p>
        </div>
        <?php
    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.1
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'GamiPress' ) )
            return false;

        // Requirements on multisite install
        if( is_multisite() && gamipress_is_network_wide_active() && is_main_site() ) {
            // On main site, need to check if integrated plugin is installed on any sub site to load all configuration files
            if( gamipress_is_plugin_active_on_network( 'thrive-quiz-builder/thrive-quiz-builder.php' ) )
                return true;
        }

        if ( ! class_exists( 'Thrive_Quiz_Builder' ) )
            return false;

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.1
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = GAMIPRESS_THRIVE_QUIZ_BUILDER_DIR . '/languages/';
        $lang_dir = apply_filters( 'gamipress_thrive_quiz_builder_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gamipress-thrive-quiz-builder-integration' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'gamipress-thrive-quiz-builder-integration', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/gamipress-thrive-quiz-builder-integration/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/gamipress-thrive-quiz-builder-integration/ folder
            load_textdomain( 'gamipress-thrive-quiz-builder-integration', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/gamipress-thrive-quiz-builder-integration/languages/ folder
            load_textdomain( 'gamipress-thrive-quiz-builder-integration', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'gamipress-thrive-quiz-builder-integration', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true GamiPress_Thrive_Quiz_Builder instance to functions everywhere
 *
 * @since       1.0.1
 * @return      \GamiPress_Thrive_Quiz_Builder The one true GamiPress_Thrive_Quiz_Builder
 */
function GamiPress_Thrive_Quiz_Builder() {
    return GamiPress_Thrive_Quiz_Builder::instance();
}
add_action( 'plugins_loaded', 'GamiPress_Thrive_Quiz_Builder' );

